@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 require 'gtk2'
-require File.expand_path(File.join(File.dirname(__FILE__), '..', 'utils'))
+require_relative '../utils'
 miquire :mui, 'crud'
 
 =begin rdoc
