@@ -13,7 +13,7 @@ module Plugin::DirectMessage
       interval
     end
 
-    on_world_create do |world|
+    on_world_after_created do |world|
       refresh_tab
     end
 
